@@ -37,9 +37,9 @@ from typing import Iterable, Optional, Tuple
 
 import click
 
-from .. import __version__
-from .custom import CustomCommand, DeprecatedOptionsCommand
-from .utility import ContextInfo
+from tensorbay import __version__
+from tensorbay.cli.custom import CustomCommand, DeprecatedOptionsCommand
+from tensorbay.cli.utility import ContextInfo
 
 
 @click.group(context_settings={"help_option_names": ("-h", "--help")})
@@ -74,7 +74,7 @@ def cli(ctx: click.Context, access_key: str, url: str, profile_name: str, debug:
         debug: Debug mode flag.
 
     """  # noqa: D301,D415
-    from .utility import _implement_cli
+    from tensorbay.cli.utility import _implement_cli
 
     _implement_cli(ctx, access_key, url, profile_name, debug)
 
@@ -101,13 +101,13 @@ def ls(  # pylint: disable=invalid-name
     """List data under the path. If path is empty, list the names of all datasets.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: Path to be listed, like "tb:KITTI:seg1". If empty, list names of all datasets.
         list_all_files: If true, list all files under the segment.
         show_total_num: If true, show the total number of resources.
 
     """  # noqa: D301,D415
-    from .ls import _implement_ls
+    from tensorbay.cli.ls import _implement_ls
 
     _implement_ls(obj, tbrn, list_all_files, show_total_num)
 
@@ -127,13 +127,13 @@ def config(obj: ContextInfo, key: str, value: str, unset: bool) -> None:
     """Configure the options when using gas CLI.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         key: The option key.
         value: The option value.
         unset: Whether to unset the option.
 
     """  # noqa: D301,D415
-    from .config import _implement_config
+    from tensorbay.cli.config import _implement_config
 
     _implement_config(obj, key, value, unset)
 
@@ -153,13 +153,13 @@ def dataset(obj: ContextInfo, tbrn: str, is_delete: bool, yes: bool) -> None:
     """List, create or delete datasets.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The tbrn of the dataset, like "tb:KITTI".
         is_delete: Whether to delete the TensorBay dataset.
         yes: Confirm to delete the dataset completely.
 
     """  # noqa: D301,D415
-    from .dataset import _implement_dataset
+    from tensorbay.cli.dataset import _implement_dataset
 
     _implement_dataset(obj, tbrn, is_delete, yes)
 
@@ -195,7 +195,7 @@ def draft(  # pylint: disable=too-many-arguments
     """List or create drafts.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The tbrn of the dataset.
         is_list: Whether to list the drafts.
         edit: Whether to edit the draft's title and description.
@@ -203,7 +203,7 @@ def draft(  # pylint: disable=too-many-arguments
         message: The message of the draft.
 
     """  # noqa: D301,D415
-    from .draft import _implement_draft
+    from tensorbay.cli.draft import _implement_draft
 
     _implement_draft(obj, tbrn, is_list, edit, close, message)
 
@@ -220,12 +220,12 @@ def commit(obj: ContextInfo, tbrn: str, message: Tuple[str, ...]) -> None:
     """Commit drafts.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The path to commit a draft, like "tb:KITTI#1".
         message: The message of the commit.
 
     """  # noqa: D301,D415
-    from .commit import _implement_commit
+    from tensorbay.cli.commit import _implement_commit
 
     _implement_commit(obj, tbrn, message)
 
@@ -267,7 +267,7 @@ def cp(  # pylint: disable=invalid-name, too-many-arguments
     """Copy local data to a remote path.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         local_paths: An iterable of local paths contains data to be uploaded.
         tbrn: The path to save the uploaded data, like "tb:KITTI:seg1".
         is_recursive: Whether copy directories recursively.
@@ -275,7 +275,7 @@ def cp(  # pylint: disable=invalid-name, too-many-arguments
         skip_uploaded_files: Whether skip the uploaded files.
 
     """  # noqa: D301,D415
-    from .cp import _implement_cp
+    from tensorbay.cli.cp import _implement_cp
 
     _implement_cp(obj, local_paths, tbrn, is_recursive, jobs, skip_uploaded_files)
 
@@ -291,21 +291,23 @@ def cp(  # pylint: disable=invalid-name, too-many-arguments
 )
 @click.argument("tbrn", type=str)
 @click.option(
-    "-r", "--recursive", "is_recursive", is_flag=True, help="Remove directories recursively."
+    "-r",
+    "--recursive",
+    "is_recursive",
+    is_flag=True,
+    help="Remove directories recursively.",  # pylint: disable=invalid-name
 )
 @click.pass_obj
-def rm(  # pylint: disable=invalid-name, too-many-arguments
-    obj: ContextInfo, tbrn: str, is_recursive: bool
-) -> None:
+def rm(obj: ContextInfo, tbrn: str, is_recursive: bool) -> None:
     """Remove the remote data.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The path to be removed, like "tb:KITTI#1".
         is_recursive: Whether remove directories recursively.
 
     """  # noqa: D301,D415
-    from .rm import _implement_rm
+    from tensorbay.cli.rm import _implement_rm
 
     _implement_rm(obj, tbrn, is_recursive)
 
@@ -326,14 +328,14 @@ def branch(obj: ContextInfo, tbrn: str, name: str, verbose: bool, is_delete: boo
     """List, create or delete branches.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The tbrn of the dataset.
         name: The name of the branch to be created.
         verbose: Whether to show the short commit id and commit message.
         is_delete: Whether to delete the branch.
 
     """  # noqa: D301,D415
-    from .branch import _implement_branch
+    from tensorbay.cli.branch import _implement_branch
 
     _implement_branch(obj, tbrn, name, verbose, is_delete)
 
@@ -353,13 +355,13 @@ def tag(obj: ContextInfo, tbrn: str, name: str, is_delete: bool) -> None:
     """List, create or delete tags.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The tbrn of the dataset.
         name: The name of the tag.
         is_delete: Whether to delete the tag.
 
     """  # noqa: D301,D415
-    from .tag import _implement_tag
+    from tensorbay.cli.tag import _implement_tag
 
     _implement_tag(obj, tbrn, name, is_delete)
 
@@ -401,7 +403,7 @@ def log(  # pylint: disable=too-many-arguments
     """Show commit logs.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         tbrn: The tbrn of a dataset.
         max_count: Max number of commits to show.
         oneline: Whether to show a commit message in oneline.
@@ -409,7 +411,7 @@ def log(  # pylint: disable=too-many-arguments
         graph: Whether to show graphical commit history.
 
     """  # noqa: D301,D415
-    from .log import _implement_log
+    from tensorbay.cli.log import _implement_log
 
     _implement_log(obj, tbrn, max_count, oneline, is_all, graph)
 
@@ -444,7 +446,7 @@ def auth(  # pylint: disable=too-many-arguments
     """Authenticate the accessKey of gas.\f
 
     Arguments:
-        obj: A NamedTuple containing the command context.
+        obj: A :class:`.utility.ContextInfo` instance containing the command context.
         arg1: The accessKey or the url of gas for the authentication.
         arg2: The accessKey of gas for the authentication if arg1 is url.
         get: Whether to get the accesskey of the profile.
@@ -453,7 +455,7 @@ def auth(  # pylint: disable=too-many-arguments
         is_all: All the auth info or not.
 
     """  # noqa: D301,D415
-    from .auth import _implement_auth
+    from tensorbay.cli.auth import _implement_auth
 
     _implement_auth(obj, arg1, arg2, get, status, unset, is_all)
 
