@@ -7,8 +7,8 @@
 
 import click
 
-from .tbrn import TBRN, TBRNType
-from .utility import ContextInfo, error, exception_handler
+from tensorbay.cli.tbrn import TBRN, TBRNType
+from tensorbay.cli.utility import ContextInfo, error, exception_handler
 
 
 @exception_handler
@@ -19,6 +19,7 @@ def _implement_dataset(obj: ContextInfo, tbrn: str, is_delete: bool, yes: bool)
             error("Missing argument TBRN")
         for dataset_name in gas.list_dataset_names():
             click.echo(TBRN(dataset_name).get_tbrn())
+        return
 
     tbrn_info = TBRN(tbrn=tbrn)
     if tbrn_info.type != TBRNType.DATASET:
