@@ -6,6 +6,7 @@
 """Implementation of gas log."""
 
 import bisect
+import sys
 from collections import defaultdict
 from datetime import datetime
 from itertools import cycle, islice, zip_longest
@@ -14,11 +15,11 @@ from typing import DefaultDict, Dict, Iterator, List, Optional, Type, Union
 
 import click
 
-from ..client.gas import DatasetClientType
-from ..client.struct import Commit
-from .auth import INDENT
-from .tbrn import TBRN, TBRNType
-from .utility import ContextInfo, error, exception_handler, is_win, shorten
+from tensorbay.cli.auth import INDENT
+from tensorbay.cli.tbrn import TBRN, TBRNType
+from tensorbay.cli.utility import ContextInfo, error, exception_handler, shorten
+from tensorbay.client.gas import DatasetClientType
+from tensorbay.client.struct import Commit
 
 _LEFT_BRACKET = click.style("(", fg="yellow", reset=False)
 _COMMA = click.style(", ", fg="yellow", reset=False)
@@ -83,7 +84,7 @@ def _implement_log(  # pylint: disable=too-many-arguments
         Printer(dataset_client, revisions, commit_id_to_branches, oneline).generate_commits(),
         max_count,
     )
-    if is_win():
+    if sys.platform.startswith("win"):
         for item in commit_generator:
             click.echo(item)
     else:
