@@ -16,14 +16,14 @@ from typing import Any, Callable, Iterable, Optional, Tuple, TypeVar, overload
 import click
 from typing_extensions import Literal, NoReturn
 
-from ..client import GAS
-from ..client import config as client_config
-from ..client.dataset import DatasetClient, FusionDatasetClient
-from ..client.gas import DatasetClientType
-from ..client.log import dump_request_and_response
-from ..client.requests import logger
-from ..exception import InternalServerError, TensorBayException
-from .tbrn import TBRN
+from tensorbay.cli.tbrn import TBRN
+from tensorbay.client import GAS
+from tensorbay.client import config as client_config
+from tensorbay.client.dataset import DatasetClient, FusionDatasetClient
+from tensorbay.client.gas import DatasetClientType
+from tensorbay.client.log import dump_request_and_response
+from tensorbay.client.requests import logger
+from tensorbay.exception import InternalServerError, TensorBayException
 
 _Callable = TypeVar("_Callable", bound=Callable[..., None])
 INDENT = " " * 4
@@ -51,8 +51,7 @@ class ContextInfo:
             The path of the config file.
 
         """
-        home = "USERPROFILE" if is_win() else "HOME"
-        return os.path.join(os.environ[home], ".gasconfig")
+        return os.path.join(os.path.expanduser("~"), ".gasconfig")
 
     @staticmethod
     def _is_updated(profile_section: SectionProxy) -> bool:
@@ -196,7 +195,7 @@ class ContextInfo:
             )
 
         config_file = self._get_config_filepath()
-        with open(config_file, "w") as fp:
+        with open(config_file, "w", encoding="utf-8") as fp:
             config_parser.write(fp)
         if show_message:
             click.echo(f'Success!\nConfiguration has been written into: "{config_file}"')
@@ -214,16 +213,6 @@ def _implement_cli(
         logger.disabled = True
 
 
-def is_win() -> bool:
-    """Determine whether the current system is Windows.
-
-    Returns:
-        Whether the current system is Windows.
-
-    """
-    return sys.platform.startswith("win")
-
-
 @overload
 def get_dataset_client(
     gas: GAS, tbrn_info: TBRN, is_fusion: Literal[None] = None
