@@ -11,11 +11,11 @@ The :class:`CloudClient` defines the initial client to interact between local an
 
 from typing import Any, Dict, Iterator, List
 
-from ..dataset import AuthData
-from .requests import Client
+from tensorbay.client.requests import Client
+from tensorbay.dataset import AuthData
 
 
-class CloudClient:  # pylint: disable=too-few-public-methods
+class CloudClient:
     """:class:`CloudClient` defines the client to interact between local and cloud platform.
 
     Arguments:
@@ -61,5 +61,5 @@ class CloudClient:  # pylint: disable=too-few-public-methods
 
         """
         return [
-            AuthData(cloud_path, url_getter=self._get_url) for cloud_path in self._list_files(path)
+            AuthData(cloud_path, _url_getter=self._get_url) for cloud_path in self._list_files(path)
         ]
