@@ -18,16 +18,15 @@ from typing import Any, Dict, Generator, Optional, Type, Union, overload
 
 from typing_extensions import Literal
 
-from ..dataset import Dataset, FusionDataset
-from ..exception import DatasetTypeError, ResourceNotExistError
-from ..utility import Deprecated
-from .cloud_storage import CloudClient
-from .dataset import DatasetClient, FusionDatasetClient
-from .lazy import PagingList
-from .log import UPLOAD_DATASET_RESUME_TEMPLATE
-from .requests import Client, Tqdm
-from .status import Status
-from .struct import ROOT_COMMIT_ID, UserInfo
+from tensorbay.client.cloud_storage import CloudClient
+from tensorbay.client.dataset import DatasetClient, FusionDatasetClient
+from tensorbay.client.lazy import PagingList
+from tensorbay.client.log import UPLOAD_DATASET_RESUME_TEMPLATE
+from tensorbay.client.requests import Client, Tqdm
+from tensorbay.client.status import Status
+from tensorbay.client.struct import ROOT_COMMIT_ID, UserInfo
+from tensorbay.dataset import Dataset, FusionDataset
+from tensorbay.exception import DatasetTypeError, ResourceNotExistError
 
 DatasetClientType = Union[DatasetClient, FusionDatasetClient]
 
@@ -328,6 +327,7 @@ class GAS:
         *,
         config_name: Optional[str] = None,
         alias: str = "",
+        is_public: bool = DEFAULT_IS_PUBLIC,
     ) -> DatasetClient:
         ...
 
@@ -339,6 +339,7 @@ class GAS:
         *,
         config_name: Optional[str] = None,
         alias: str = "",
+        is_public: bool = DEFAULT_IS_PUBLIC,
     ) -> FusionDatasetClient:
         ...
 
@@ -350,6 +351,7 @@ class GAS:
         *,
         config_name: Optional[str] = None,
         alias: str = "",
+        is_public: bool = DEFAULT_IS_PUBLIC,
     ) -> DatasetClientType:
         ...
 
@@ -360,6 +362,7 @@ class GAS:
         *,
         config_name: Optional[str] = None,
         alias: str = "",
+        is_public: bool = DEFAULT_IS_PUBLIC,
     ) -> DatasetClientType:
         """Create a TensorBay dataset with given name.
 
@@ -368,6 +371,7 @@ class GAS:
             is_fusion: Whether the dataset is a fusion dataset, True for fusion dataset.
             config_name: The auth storage config name.
             alias: Alias of the dataset, default is "".
+            is_public: Whether the dataset is a public dataset.
 
         Returns:
             The created :class:`~tensorbay.client.dataset.DatasetClient` instance or
@@ -379,6 +383,7 @@ class GAS:
             "name": name,
             "type": int(is_fusion),  # normal dataset: 0, fusion dataset: 1
             "alias": alias,
+            "isPublic": is_public,
         }
         if config_name is not None:
             post_data["configName"] = config_name
@@ -393,37 +398,9 @@ class GAS:
             self,
             status=status,
             alias=alias,
-            is_public=DEFAULT_IS_PUBLIC,
+            is_public=is_public,
         )
 
-    @Deprecated(since="1.12.0", removed_in="1.15.0", substitute="GAS.create_dataset")
-    def create_auth_dataset(
-        self,
-        name: str,
-        is_fusion: bool = False,
-        *,
-        config_name: Optional[str] = None,
-        alias: str = "",
-    ) -> DatasetClientType:
-        """Create a TensorBay dataset with given name in auth cloud storage.
-
-        The dataset will be linked to the given auth cloud storage
-            and all of relative data will be stored in auth cloud storage.
-
-        Arguments:
-            name: Name of the dataset, unique for a user.
-            is_fusion: Whether the dataset is a fusion dataset, True for fusion dataset.
-            config_name: The auth storage config name.
-            alias: Alias of the dataset, default is "".
-
-        Returns:
-            The created :class:`~tensorbay.client.dataset.DatasetClient` instance or
-            :class:`~tensorbay.client.dataset.FusionDatasetClient` instance (is_fusion=True),
-            and the status of dataset client is "commit".
-
-        """
-        return self.create_dataset(name, is_fusion, config_name=config_name, alias=alias)
-
     @overload
     def get_dataset(self, name: str, is_fusion: Literal[False] = False) -> DatasetClient:
         ...
