@@ -19,6 +19,7 @@ from queue import Queue
 from threading import Lock
 from typing import Any, Callable, DefaultDict, Generic, Iterable, Optional, Tuple, TypeVar
 from urllib.parse import urljoin
+from uuid import uuid4
 
 import urllib3
 from requests import Session
@@ -28,9 +29,9 @@ from requests.models import PreparedRequest, Response
 from tqdm import tqdm
 from urllib3.util.retry import Retry
 
-from ..__version__ import __version__
-from ..exception import ResponseError, ResponseErrorDistributor
-from .log import RequestLogging, ResponseLogging
+from tensorbay.__version__ import __version__
+from tensorbay.client.log import RequestLogging, ResponseLogging
+from tensorbay.exception import ResponseError, ResponseErrorDistributor
 
 logger = logging.getLogger(__name__)
 
@@ -133,7 +134,7 @@ class UserSession(Session):
         self.mount("http://", TimeoutHTTPAdapter(20, 20, retry_strategy))
         self.mount("https://", TimeoutHTTPAdapter(20, 20, retry_strategy))
 
-    def request(  # type: ignore[override]  # pylint: disable=signature-differs
+    def request(  # type: ignore[override]
         self, method: str, url: str, *args: Any, **kwargs: Any
     ) -> Response:  # noqa: DAR401
         """Make the request.
@@ -257,10 +258,12 @@ class Client:
             Response of the request.
 
         """
-        kwargs.setdefault("headers", {})["X-Token"] = self.access_key
-        kwargs["headers"][
+        headers = kwargs.setdefault("headers", {})
+        headers["X-Token"] = self.access_key
+        headers[
             "X-Source"
         ] = f"{config._x_source}/{__version__}"  # pylint: disable=protected-access
+        headers["X-Request-Id"] = uuid4().hex
 
         try:
             return self.do(method=method, url=self._url_make(section, dataset_id), **kwargs)
@@ -271,9 +274,7 @@ class Client:
                 response=response
             ) from None
 
-    def do(  # pylint: disable=function-redefined,invalid-name
-        self, method: str, url: str, **kwargs: Any
-    ) -> Response:
+    def do(self, method: str, url: str, **kwargs: Any) -> Response:  # pylint: disable=invalid-name
         """Send a request.
 
         Arguments:
