@@ -23,6 +23,7 @@ for more information.
 
 """
 
+import os
 import time
 from copy import deepcopy
 from itertools import zip_longest
@@ -32,17 +33,17 @@ import filetype
 from requests_toolbelt import MultipartEncoder
 from ulid import ULID, from_timestamp
 
-from ..dataset import AuthData, Data, Frame, RemoteData
-from ..exception import FrameError, InvalidParamsError, ResponseError
-from ..label import Label
-from ..sensor.sensor import Sensor, Sensors
-from ..utility import FileMixin, chunked, locked
-from .lazy import LazyPage, PagingList
-from .requests import config
-from .status import Status
+from tensorbay.client.lazy import LazyPage, PagingList
+from tensorbay.client.requests import config
+from tensorbay.client.status import Status
+from tensorbay.dataset import AuthData, Data, Frame, RemoteData
+from tensorbay.exception import FrameError, InvalidParamsError, ResponseError
+from tensorbay.label import Label
+from tensorbay.sensor.sensor import Sensor, Sensors
+from tensorbay.utility import FileMixin, chunked, locked
 
 if TYPE_CHECKING:
-    from .dataset import DatasetClient, FusionDatasetClient
+    from tensorbay.client.dataset import DatasetClient, FusionDatasetClient
 
 _STRATEGIES = {"abort", "override", "skip"}
 _MASK_KEYS = ("semantic_mask", "instance_mask", "panoptic_mask")
@@ -60,7 +61,7 @@ class _UrlGetters:
         self._urls.pull()
 
 
-class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
+class SegmentClientBase:
     """This class defines the basic concept of :class:`SegmentClient`.
 
     A :class:`SegmentClientBase` contains the information needed for determining
@@ -86,9 +87,18 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         self._dataset_id = dataset_client.dataset_id
         self._dataset_client = dataset_client
         self._status = dataset_client.status
-        self._client = dataset_client._client  # pylint: disable=protected-access
+        self._client = dataset_client._client
         self._permission: Dict[str, Any] = {"expireAt": 0}
 
+        if dataset_client.cache_enabled:
+            self._cache_path: str = os.path.join(
+                dataset_client._cache_path,
+                dataset_client.status.commit_id,  # type: ignore[arg-type]
+                name,
+            )
+        else:
+            self._cache_path = ""
+
     def _get_url(self, remote_path: str) -> str:
         """Get URL of a specific remote path.
 
@@ -265,6 +275,16 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
             }
             self._client.do("PUT", url, data=fp, headers=request_headers)
 
+    def _synchronize_import_info(self, callback_bodies: Tuple[Dict[str, Any], ...]) -> None:
+        put_data: Dict[str, Any] = {
+            "segmentName": self.name,
+            "objects": callback_bodies,
+            "deleteSource": False,
+        }
+        put_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("PUT", "multi/cloud-callback", self._dataset_id, json=put_data)
+
     def _synchronize_upload_info(
         self,
         callback_bodies: Tuple[Dict[str, Any], ...],
@@ -370,6 +390,7 @@ class SegmentClient(SegmentClientBase):
                 item,
                 _url_getter=urls[i],
                 _url_updater=urls.update,
+                cache_path=self._cache_path,
             )
             label = data.label
             for key in _MASK_KEYS:
@@ -378,6 +399,7 @@ class SegmentClient(SegmentClientBase):
                     # pylint: disable=protected-access
                     mask._url_getter = mask_urls[key][i]
                     mask._url_updater = mask_urls[key].update
+                    mask.cache_path = os.path.join(self._cache_path, key, mask.path)
 
             yield data
 
@@ -407,7 +429,7 @@ class SegmentClient(SegmentClientBase):
             self._upload_mask_files(data.label)
             return data.get_callback_body()
 
-        self.import_auth_data(data)
+        self._synchronize_import_info((data.get_callback_body(),))
         return None
 
     def upload_file(self, local_path: str, target_remote_path: str = "") -> None:
@@ -457,19 +479,7 @@ class SegmentClient(SegmentClientBase):
 
         """
         self._status.check_authority_for_draft()
-        put_data: Dict[str, Any] = {
-            "segmentName": self.name,
-            "objects": [
-                {
-                    "cloudPath": data.path,
-                    "remotePath": data.target_remote_path,
-                    "label": data.label.dumps(),
-                }
-            ],
-            "deleteSource": False,
-        }
-        put_data.update(self._status.get_status_info())
-        self._client.open_api_do("PUT", "multi/cloud-callback", self._dataset_id, json=put_data)
+        self._synchronize_import_info((data.get_callback_body(),))
 
     def copy_data(
         self,
@@ -626,7 +636,7 @@ class SegmentClient(SegmentClientBase):
             if (
                 source_client.status.draft_number == self.status.draft_number
                 and source_client._dataset_id  # pylint: disable=protected-access
-                == self._dataset_id  # pylint: disable=protected-access
+                == self._dataset_id
             ):
                 source["segmentName"] = source_client.name
             else:
@@ -744,7 +754,7 @@ class FusionSegmentClient(SegmentClientBase):
         )
 
         for index, item in enumerate(response["dataDetails"]):
-            yield Frame.from_response_body(item, index, url_page)
+            yield Frame.from_response_body(item, index, url_page, cache_path=self._cache_path)
 
         return response["totalCount"]  # type: ignore[no-any-return]
 
@@ -764,14 +774,16 @@ class FusionSegmentClient(SegmentClientBase):
         sensor_name: str,
         frame_id: str,
     ) -> Optional[Dict[str, Any]]:
+        callback_body = data.get_callback_body()
+        callback_body["frameId"] = frame_id
+        callback_body["sensorName"] = sensor_name
+
         if isinstance(data, Data):
             self._upload_file(data)
             self._upload_mask_files(data.label)
-
-            callback_body = data.get_callback_body()
-            callback_body["frameId"] = frame_id
-            callback_body["sensorName"] = sensor_name
             return callback_body
+
+        self._synchronize_import_info((callback_body,))
         return None
 
     def get_sensors(self) -> Sensors:
@@ -847,16 +859,19 @@ class FusionSegmentClient(SegmentClientBase):
 
         callback_bodies = []
         for sensor_name, data in frame.items():
-            if not isinstance(data, Data):
+            try:
+                callback_body = data.get_callback_body()  # type:ignore[union-attr]
+            except AttributeError:
                 continue
 
-            self._upload_file(data)
-            self._upload_mask_files(data.label)
-
-            callback_body = data.get_callback_body()
             callback_body["frameId"] = frame_id.str
             callback_body["sensorName"] = sensor_name
-            callback_bodies.append(callback_body)
+            if isinstance(data, Data):
+                self._upload_file(data)
+                self._upload_mask_files(data.label)
+                callback_bodies.append(callback_body)
+            elif isinstance(data, AuthData):
+                self._synchronize_import_info((callback_body,))
 
         for chunked_callback_bodies in chunked(callback_bodies, 50):
             self._synchronize_upload_info(chunked_callback_bodies)
