@@ -29,6 +29,7 @@ from typing import (
     Dict,
     Iterable,
     KeysView,
+    List,
     Optional,
     Sequence,
     Tuple,
@@ -38,26 +39,27 @@ from typing import (
     overload,
 )
 
-from ..label import Catalog
-from ..utility import (
-    Deprecated,
-    EqMixin,
+from tensorbay.dataset.segment import FusionSegment, Segment
+from tensorbay.label import Catalog
+from tensorbay.utility import (
+    AttrsMixin,
     NameMixin,
-    NameSortedList,
     ReprMixin,
     ReprType,
+    SortedNameList,
+    attr,
+    camel,
     common_loads,
     locked,
 )
-from .segment import FusionSegment, Segment
 
 if TYPE_CHECKING:
-    from ..client import GAS
+    from tensorbay.client import GAS
 
 _T = TypeVar("_T", FusionSegment, Segment)
 
 
-class Notes(ReprMixin, EqMixin):
+class Notes(AttrsMixin, ReprMixin):
     """This is a class stores the basic information of :class:`DatasetBase`.
 
     Arguments:
@@ -70,11 +72,16 @@ class Notes(ReprMixin, EqMixin):
 
     _repr_attrs = ("is_continuous", "bin_point_cloud_fields")
 
+    is_continuous: bool = attr(key=camel, default=False)
+    bin_point_cloud_fields: Optional[List[str]] = attr(key=camel, default=None)
+
     def __init__(
         self, is_continuous: bool = False, bin_point_cloud_fields: Optional[Iterable[str]] = None
     ) -> None:
         self.is_continuous = is_continuous
-        self.bin_point_cloud_fields = bin_point_cloud_fields
+        self.bin_point_cloud_fields = (
+            list(bin_point_cloud_fields) if bin_point_cloud_fields else None
+        )
 
     def __getitem__(self, key: str) -> Any:
         try:
@@ -82,10 +89,6 @@ class Notes(ReprMixin, EqMixin):
         except AttributeError as error:
             raise KeyError(key) from error
 
-    def _loads(self, contents: Dict[str, Any]) -> None:
-        self.is_continuous = contents["isContinuous"]
-        self.bin_point_cloud_fields = contents.get("binPointCloudFields")
-
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
         """Loads a :class:`Notes` instance from the given contents.
@@ -131,13 +134,12 @@ class Notes(ReprMixin, EqMixin):
                 }
 
         """
-        contents: Dict[str, Any] = {"isContinuous": self.is_continuous}
-        if self.bin_point_cloud_fields:
-            contents["binPointCloudFields"] = self.bin_point_cloud_fields
-        return contents
+        return self._dumps()
 
 
-class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestors
+# When the NameMixin is before Sequence[_T], typing will raise AttributeError.
+# related issue: python/typing#777
+class DatasetBase(Sequence[_T], NameMixin):
     """This class defines the concept of a basic dataset.
 
     DatasetBase represents a whole dataset contains several segments
@@ -162,7 +164,10 @@ class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestor
     _repr_type = ReprType.SEQUENCE
 
     def __init__(
-        self, name: str, gas: Optional["GAS"] = None, revision: Optional[str] = None
+        self,
+        name: str,
+        gas: Optional["GAS"] = None,
+        revision: Optional[str] = None,
     ) -> None:
         super().__init__(name)
 
@@ -171,7 +176,7 @@ class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestor
             if revision:
                 self._client.checkout(revision)
         else:
-            self._segments: NameSortedList[_T] = NameSortedList()
+            self._segments: SortedNameList[_T] = SortedNameList()
             self._catalog = Catalog()
             self._notes = Notes()
 
@@ -187,30 +192,26 @@ class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestor
         ...
 
     def __getitem__(self, index: Union[int, str, slice]) -> Union[Sequence[_T], _T]:
-        if isinstance(index, str):
-            return self._get_segments().get_from_name(index)
-
         return self._get_segments().__getitem__(index)
 
     def __delitem__(self, index: Union[int, str, slice]) -> None:
-        if isinstance(index, slice):
-            for key in self._get_segments()._data.keys()[index]:
-                self._get_segments()._data.__delitem__(key)
-            return
+        return self._get_segments().__delitem__(index)
 
-        if isinstance(index, int):
-            index = self._get_segments()._data.keys()[index]
+    def __contains__(self, key: Any) -> bool:
+        return self._get_segments().__contains__(key)
 
-        self._get_segments()._data.__delitem__(index)
+    def _assert_remote(self) -> None:
+        if not hasattr(self, "_client"):
+            raise TypeError("Cache is only for remote datasets")
 
     @locked
     def _init_segments(self) -> None:
-        self._segments = NameSortedList()
-        # pylint: disable=protected-access
-        for segment in self._client._list_segment_instances():
+        self._segments = SortedNameList()
+
+        for segment in self._client._list_segment_instances():  # pylint: disable=protected-access
             self._segments.add(segment)  # type: ignore[arg-type]
 
-    def _get_segments(self) -> NameSortedList[_T]:
+    def _get_segments(self) -> SortedNameList[_T]:
         if not hasattr(self, "_segments"):
             self._init_segments()
 
@@ -242,6 +243,27 @@ class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestor
 
         return self._notes
 
+    @property
+    def cache_enabled(self) -> bool:
+        """Whether the cache is enabled.
+
+        Returns:
+            Whether the cache is enabled.
+
+        """
+        self._assert_remote()
+        return self._client.cache_enabled
+
+    def enable_cache(self, cache_path: str = "") -> None:
+        """Enable cache when open the remote data of the dataset.
+
+        Arguments:
+            cache_path: The path to store the cache.
+
+        """
+        self._assert_remote()
+        self._client.enable_cache(cache_path)
+
     def keys(self) -> Tuple[str, ...]:
         """Get all segment names.
 
@@ -249,8 +271,7 @@ class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestor
             A tuple containing all segment names.
 
         """
-        # pylint: disable=protected-access
-        return tuple(self._get_segments()._data)
+        return self._get_segments().keys()
 
     def load_catalog(self, filepath: str) -> None:
         """Load catalog from a json file.
@@ -259,23 +280,10 @@ class DatasetBase(NameMixin, Sequence[_T]):  # pylint: disable=too-many-ancestor
             filepath: The path of the json file which contains the catalog information.
 
         """
-        with open(filepath, "r") as fp:
+        with open(filepath, "r", encoding="utf-8") as fp:
             contents = json.load(fp)
         self._catalog = Catalog.loads(contents)
 
-    @Deprecated(since="v1.4.0", removed_in="v1.7.0", substitute=__getitem__)
-    def get_segment_by_name(self, name: str) -> _T:
-        """Return the segment corresponding to the given name.
-
-        Arguments:
-            name: The name of the request segment.
-
-        Returns:
-            The segment which matches the input name.
-
-        """
-        return self._get_segments().get_from_name(name)
-
     def add_segment(self, segment: _T) -> None:
         """Add a segment to the dataset.
 
@@ -296,7 +304,7 @@ class Dataset(DatasetBase[Segment]):
 
     _is_fusion = False
 
-    def create_segment(self, segment_name: str = "") -> Segment:
+    def create_segment(self, segment_name: str = "default") -> Segment:
         """Create a segment with the given name.
 
         Arguments:
@@ -320,7 +328,7 @@ class FusionDataset(DatasetBase[FusionSegment]):
 
     _is_fusion = True
 
-    def create_segment(self, segment_name: str = "") -> FusionSegment:
+    def create_segment(self, segment_name: str = "default") -> FusionSegment:
         """Create a fusion segment with the given name.
 
         Arguments:
