@@ -19,9 +19,9 @@ from uuid import UUID
 
 from ulid import ULID, from_str, from_uuid
 
-from ..client.lazy import LazyPage
-from ..utility import UserMutableMapping
-from .data import DataBase, RemoteData
+from tensorbay.client.lazy import LazyPage
+from tensorbay.dataset.data import DataBase, RemoteData
+from tensorbay.utility import UserMutableMapping
 
 logger = logging.getLogger(__name__)
 
@@ -64,7 +64,12 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
 
     @classmethod
     def from_response_body(
-        cls: Type[_T], body: Dict[str, Any], url_index: int, urls: LazyPage[Dict[str, str]]
+        cls: Type[_T],
+        body: Dict[str, Any],
+        url_index: int,
+        urls: LazyPage[Dict[str, str]],
+        *,
+        cache_path: str = "",
     ) -> _T:
         """Loads a :class:`Frame` object from a response body.
 
@@ -88,6 +93,7 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
                     }
             url_index: The index of the url.
             urls: A sequence of mappings which key is the sensor name and value is the url.
+            cache_path: The path to store the cache.
 
         Returns:
             The loaded :class:`Frame` object.
@@ -99,8 +105,8 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
             # Legacy fusion dataset use uuid as frame ID
             # Keep this code here to make SDK compatible with uuid
             frame_id = from_uuid(UUID(body["frameId"]))
-            if cls._logger_flag:  # pylint: disable=protected-access
-                cls._logger_flag = False  # pylint: disable=protected-access
+            if cls._logger_flag:
+                cls._logger_flag = False
                 logger.warning(
                     "WARNING: This is a legacy fusion dataset which use uuid as frame ID, "
                     "it should be updated to ulid."
@@ -114,6 +120,7 @@ class Frame(UserMutableMapping[str, "DataBase._Type"]):
                     url_index
                 ].get()[s],
                 _url_updater=urls.pull,
+                cache_path=cache_path,
             )
         return frame
 
