@@ -7,9 +7,9 @@
 
 from typing import Any, Callable, Dict, Optional, Type, TypeVar
 
-from ..utility import FileMixin, RemoteFileMixin, ReprMixin
-from .basic import AttributeType, SubcatalogBase
-from .supports import AttributesMixin, IsTrackingMixin, MaskCategoriesMixin
+from tensorbay.label.basic import AttributeType, SubcatalogBase
+from tensorbay.label.supports import AttributesMixin, IsTrackingMixin, MaskCategoriesMixin
+from tensorbay.utility import FileMixin, RemoteFileMixin, ReprMixin
 
 
 class SemanticMaskSubcatalog(SubcatalogBase, MaskCategoriesMixin, AttributesMixin):
@@ -502,8 +502,11 @@ class RemotePanopticMask(PanopticMaskBase, RemoteFileMixin):
         """
         mask = cls(body["remotePath"])
         info = body["info"]
-        mask.all_category_ids = {item["instanceId"]: item["categoryId"] for item in info}
-        if "attributes" in info[0]:
-            mask.all_attributes = {item["instanceId"]: item["attributes"] for item in body["info"]}
+        # Workaround for panoptic masks with empty info.
+        # TODO: Remove this check after reuploading COCO mask labels or changing standards.
+        if info:
+            mask.all_category_ids = {item["instanceId"]: item["categoryId"] for item in info}
+            if "attributes" in info[0]:
+                mask.all_attributes = {item["instanceId"]: item["attributes"] for item in info}
 
         return mask
