@@ -6,6 +6,6 @@
 
 """Dataloader of the BDD100K_MOT2020 dataset and the BDD100K_MOTS2020 dataset."""
 
-from .loader import BDD100K_MOT2020, BDD100K_MOTS2020
+from tensorbay.opendataset.BDD100K_MOT2020.loader import BDD100K_MOT2020, BDD100K_MOTS2020
 
 __all__ = ["BDD100K_MOT2020", "BDD100K_MOTS2020"]
