@@ -12,11 +12,11 @@ from typing import Any, Dict, List
 
 import quaternion
 
-from ...dataset import Data, Frame, FusionDataset
-from ...exception import ModuleImportError
-from ...label import LabeledBox3D
-from ...sensor import Camera, Lidar, Sensors
-from .._utility import glob
+from tensorbay.dataset import Data, Frame, FusionDataset
+from tensorbay.exception import ModuleImportError
+from tensorbay.label import LabeledBox3D
+from tensorbay.opendataset._utility import glob
+from tensorbay.sensor import Camera, Lidar, Sensors
 
 DATASET_NAME = "CADC"
 
@@ -86,12 +86,12 @@ def CADC(path: str) -> FusionDataset:
             if index == "calib":
                 continue
 
-            segment = dataset.create_segment(f"{date}/{index}")
+            segment = dataset.create_segment(f"{date}-{index}")
             segment.sensors = sensors
             segment_path = os.path.join(root_path, date, index)
             data_path = os.path.join(segment_path, "labeled")
 
-            with open(os.path.join(segment_path, "3d_ann.json"), "r") as fp:
+            with open(os.path.join(segment_path, "3d_ann.json"), "r", encoding="utf-8") as fp:
                 # The first line of the json file is the json body.
                 annotations = json.loads(fp.readline())
             timestamps = _load_timestamps(sensors, data_path)
@@ -103,10 +103,10 @@ def CADC(path: str) -> FusionDataset:
 
 def _load_timestamps(sensors: Sensors, data_path: str) -> Dict[str, List[str]]:
     timestamps = {}
-    for sensor_name in sensors:
+    for sensor_name in sensors.keys():
         data_folder = f"image_{sensor_name[-2:]}" if sensor_name != "LIDAR" else "lidar_points"
         timestamp_file = os.path.join(data_path, data_folder, "timestamps.txt")
-        with open(timestamp_file, "r") as fp:
+        with open(timestamp_file, "r", encoding="utf-8") as fp:
             timestamps[sensor_name] = fp.readlines()
 
     return timestamps
@@ -120,7 +120,7 @@ def _load_frame(
     timestamps: Dict[str, List[str]],
 ) -> Frame:
     frame = Frame()
-    for sensor_name in sensors:
+    for sensor_name in sensors.keys():
         # The data file name is a string of length 10 with each digit being a number:
         # 0000000000.jpg
         # 0000000001.bin
@@ -189,7 +189,7 @@ def _load_sensors(calib_path: str) -> Sensors:
     try:
         import yaml  # pylint: disable=import-outside-toplevel
     except ModuleNotFoundError as error:
-        raise ModuleImportError(error.name, "pyyaml") from error  # type: ignore[arg-type]
+        raise ModuleImportError(module_name=error.name, package_name="pyyaml") from error
 
     sensors = Sensors()
 
@@ -197,11 +197,11 @@ def _load_sensors(calib_path: str) -> Sensors:
     lidar.set_extrinsics()
     sensors.add(lidar)
 
-    with open(os.path.join(calib_path, "extrinsics.yaml"), "r") as fp:
+    with open(os.path.join(calib_path, "extrinsics.yaml"), "r", encoding="utf-8") as fp:
         extrinsics = yaml.load(fp, Loader=yaml.FullLoader)
 
     for camera_calibration_file in glob(os.path.join(calib_path, "[0-9]*.yaml")):
-        with open(camera_calibration_file, "r") as fp:
+        with open(camera_calibration_file, "r", encoding="utf-8") as fp:
             camera_calibration = yaml.load(fp, Loader=yaml.FullLoader)
 
         # camera_calibration_file looks like:
