@@ -9,8 +9,8 @@ import csv
 import os
 from typing import Any, Dict
 
-from ...dataset import Data, Dataset
-from ...label import Classification
+from tensorbay.dataset import Data, Dataset
+from tensorbay.label import Classification
 
 DATASET_NAME = "COVID-chestxray"
 
@@ -60,7 +60,7 @@ def COVIDChestXRay(path: str) -> Dataset:
 
     csv_path = os.path.join(root_path, "metadata.csv")
 
-    with open(csv_path) as fp:
+    with open(csv_path, encoding="utf-8") as fp:
         csv_reader = csv.DictReader(fp)
         for attributes in csv_reader:
             folder = attributes.pop("folder")
