@@ -6,6 +6,6 @@
 
 """Dataloader of the 17 Category Flower dataset and the 102 Category Flower dataset."""
 
-from .loader import Flower17, Flower102
+from tensorbay.opendataset.Flower.loader import Flower17, Flower102
 
 __all__ = ["Flower17", "Flower102"]
