@@ -3,34 +3,36 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 # pylint: disable=invalid-name
-
-"""Dataloader of the ImageEmotionAbstract dataset and the ImageEmotionArtphoto dataset."""
+# pylint: disable=missing-module-docstring
 
 import csv
 import os
 
-from ...dataset import Data, Dataset
-from ...label import Classification
-from .._utility import glob
+from tensorbay.dataset import Data, Dataset
+from tensorbay.label import Classification
+from tensorbay.opendataset._utility import glob
 
-DATASET_NAME_ABSTRACT = "ImageEmotion-abstract"
-DATASET_NAME_ARTPHOTO = "ImageEmotion-artphoto"
+DATASET_NAME_ABSTRACT = "ImageEmotionAbstract"
+DATASET_NAME_ARTPHOTO = "ImageEmotionArtPhoto"
 
 
 def ImageEmotionAbstract(path: str) -> Dataset:
-    """Dataloader of the ImageEmotionAbstract dataset.
+    """Dataloader of the `Image Emotion-abstract`_ dataset.
+
+    .. _Image Emotion-abstract: https://www.imageemotion.org/
+
+    The file structure should be like::
+
+        <path>
+            ABSTRACT_groundTruth.csv
+            abstract_xxxx.jpg
+            ...
 
     Arguments:
         path: The root directory of the dataset.
-            The file structure should be like::
-
-                <path>
-                    ABSTRACT_groundTruth.csv
-                    abstract_xxxx.jpg
-                    ...
 
     Returns:
-        Loaded `Dataset` object.
+        Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     """
     root_path = os.path.abspath(os.path.expanduser(path))
@@ -59,18 +61,21 @@ def ImageEmotionAbstract(path: str) -> Dataset:
 
 
 def ImageEmotionArtphoto(path: str) -> Dataset:
-    """Dataloader of the ImageEmotionArtphoto dataset.
+    """Dataloader of the `Image Emotion-art Photo`_ dataset.
+
+    .. _Image Emotion-art Photo: https://www.imageemotion.org/
+
+    The file structure should be like::
+
+        <path>
+            <filename>.jpg
+            ...
 
     Arguments:
         path: The root directory of the dataset.
-            The file structure should be like::
-
-                <path>
-                    <filename>.jpg
-                    ...
 
     Returns:
-        Loaded `Dataset` object
+        Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     """
     root_path = os.path.abspath(os.path.expanduser(path))
