@@ -10,10 +10,10 @@ import os
 from itertools import islice
 from typing import List
 
-from ...dataset import Data, Dataset
-from ...geometry import Keypoint2D
-from ...label import LabeledKeypoints2D, SemanticMask
-from ...utility import chunked
+from tensorbay.dataset import Data, Dataset
+from tensorbay.geometry import Keypoint2D
+from tensorbay.label import LabeledKeypoints2D, SemanticMask
+from tensorbay.utility import chunked
 
 DATASET_NAME = "LIP"
 _SEGMENT_NAMES = ("train", "val", "test")
@@ -76,13 +76,15 @@ def LIP(path: str) -> Dataset:
         segment = dataset.create_segment(segment_name)
         if segment_name == "test":
             image_path = os.path.join(test_path, "testing_images")
-            with open(os.path.join(test_path, "test_id.txt"), "r") as fp:
+            with open(os.path.join(test_path, "test_id.txt"), "r", encoding="utf-8") as fp:
                 for filename in fp:
                     segment.append(Data(os.path.join(image_path, f"{filename.rstrip()}.jpg")))
         else:
             image_path = os.path.join(trainval_image_path, f"{segment_name}_images")
             parsing_path = os.path.join(trainval_parsing_path, f"{segment_name}_segmentations")
-            with open(os.path.join(pose_path, f"lip_{segment_name}_set.csv"), "r") as csvfile:
+            with open(
+                os.path.join(pose_path, f"lip_{segment_name}_set.csv"), "r", encoding="utf-8"
+            ) as csvfile:
                 for keypoints_info in csv.reader(csvfile):
                     segment.append(_get_data(keypoints_info, image_path, parsing_path))
     return dataset
