@@ -7,10 +7,11 @@
 
 import os
 
-from ...dataset import Data, Dataset
-from ...geometry import Keypoint2D
-from ...label import LabeledKeypoints2D
-from .._utility import glob
+from tensorbay.dataset import Data, Dataset
+from tensorbay.exception import ModuleImportError
+from tensorbay.geometry import Keypoint2D
+from tensorbay.label import LabeledKeypoints2D
+from tensorbay.opendataset._utility import glob
 
 DATASET_NAME = "LeedsSportsPose"
 
@@ -32,11 +33,17 @@ def LeedsSportsPose(path: str) -> Dataset:
     Arguments:
         path: The root directory of the dataset.
 
+    Raises:
+        ModuleImportError: When the module "scipy" can not be found.
+
     Returns:
         Loaded :class:`~tensorbay.dataset.dataset.Dataset` instance.
 
     """
-    from scipy.io import loadmat  # pylint: disable=import-outside-toplevel
+    try:
+        from scipy.io import loadmat  # pylint: disable=import-outside-toplevel
+    except ModuleNotFoundError as error:
+        raise ModuleImportError(module_name=error.name) from error
 
     root_path = os.path.abspath(os.path.expanduser(path))
 
@@ -55,9 +62,7 @@ def LeedsSportsPose(path: str) -> Dataset:
 
         keypoints = LabeledKeypoints2D()
         for keypoint in joints[index]:
-            keypoints.append(  # pylint: disable=no-member  # pylint issue #3131
-                Keypoint2D(keypoint[0], keypoint[1], int(not keypoint[2]))
-            )
+            keypoints.append(Keypoint2D(keypoint[0], keypoint[1], int(not keypoint[2])))
 
         data.label.keypoints2d.append(keypoints)
         segment.append(data)
