@@ -9,9 +9,9 @@ import os
 from collections import defaultdict
 from typing import Dict, List
 
-from ...dataset import Data, Dataset
-from ...label import Box2DSubcatalog, Classification, ClassificationSubcatalog, LabeledBox2D
-from .._utility import glob
+from tensorbay.dataset import Data, Dataset
+from tensorbay.label import Box2DSubcatalog, Classification, ClassificationSubcatalog, LabeledBox2D
+from tensorbay.opendataset._utility import glob
 
 _DATASET_NAME = "UAVDT"
 
@@ -35,16 +35,16 @@ _XYWH_KEYS = _FIELDNAMES[2:6]
 def UAVDT(path: str) -> Dataset:
     """Dataloader of the `UAVDT`_ Dataset.
 
-    The "score", "in-view", "occlusion" fields in MOT Groundtruth file(*_gt.txt) are constant, and
-    other fields in that file are the same with such fields in DET Groundtruth file(*_gt_whole.txt).
-    Therefore, they are not included in the dataloader.
-
-    The Ignore Areas file(*_gt_ignore.txt) is useless, so they are not included in the dataloader
-    neither.
-
     .. _UAVDT: https://sites.google.com/site/daviddo0323/projects/uavdt
 
-    The file structure of UAVDT looks like:
+    The "score", "in-view", "occlusion" fields in MOT Groundtruth file(``*_gt.txt``) are constant,
+    and other fields in that file are the same with such fields in DET Groundtruth file
+    (``*_gt_whole.txt``). Therefore, they are not included in the dataloader.
+
+    The Ignore Areas file(``*_gt_ignore.txt``) is useless,
+    so they are not included in the dataloader neither.
+
+    The file structure of UAVDT looks like::
 
         <path>
             M_attr/
@@ -105,7 +105,7 @@ def UAVDT(path: str) -> Dataset:
 def _extract_classification(
     path: str, classification_catalog: ClassificationSubcatalog
 ) -> Classification:
-    with open(path) as fp:
+    with open(path, encoding="utf-8") as fp:
         attribute_names = classification_catalog.attributes.keys()
         csv_reader = csv.reader(fp)
         elements = next(csv_reader)
@@ -128,7 +128,7 @@ def _extract_box2d(
 
     ground_truth_path = os.path.join(path, "UAV-benchmark-MOTD_v1.0", "GT")
     frame_id_ground_truth_map = defaultdict(list)
-    with open(os.path.join(ground_truth_path, f"{sequence}_gt_whole.txt")) as fp:
+    with open(os.path.join(ground_truth_path, f"{sequence}_gt_whole.txt"), encoding="utf-8") as fp:
         for elements in csv.DictReader(fp, fieldnames=_FIELDNAMES):
             box2d = LabeledBox2D.from_xywh(
                 *(int(elements[key]) for key in _XYWH_KEYS),
