@@ -10,10 +10,14 @@ import json
 import os
 from typing import Any, Dict, Iterator, List
 
-from ...dataset import Data, Frame, FusionDataset, FusionSegment
-from ...geometry import Transform3D
-from ...label import LabeledBox3D
-from .._utility.nuScenes import get_info_with_determined_token, get_info_with_token, get_sensor
+from tensorbay.dataset import Data, Frame, FusionDataset, FusionSegment
+from tensorbay.geometry import Transform3D
+from tensorbay.label import LabeledBox3D
+from tensorbay.opendataset._utility.nuScenes import (
+    get_info_with_determined_token,
+    get_info_with_token,
+    get_sensor,
+)
 
 DATASET_NAME = "nuScenes"
 
@@ -137,7 +141,7 @@ def _get_annotation_info(info_path: str, is_test: bool = False) -> Dict[str, Any
         "ego_poses": get_info_with_token(info_path, "ego_pose"),
         "sensor": get_info_with_token(info_path, "sensor"),
     }
-    with open(os.path.join(info_path, "scene.json"), "r") as file:
+    with open(os.path.join(info_path, "scene.json"), "r", encoding="utf-8") as file:
         annotation_info["scenes"] = json.load(file)
     if not is_test:
         annotation_info["sample_annotations"] = get_info_with_determined_token(
