@@ -5,22 +5,25 @@
 
 """Utility classes."""
 
-from .attr import AttrsMixin, attr, attr_base, camel, upper
-from .common import (
+from tensorbay.utility.attr import AttrsMixin, attr, attr_base, camel, upper
+from tensorbay.utility.common import EqMixin, MatrixType, common_loads, locked
+from tensorbay.utility.deprecated import (
     DefaultValueDeprecated,
     Deprecated,
     Disable,
-    EqMixin,
     KwargsDeprecated,
-    MatrixType,
-    common_loads,
-    locked,
 )
-from .itertools import chunked
-from .name import NameList, NameMixin, SortedNameList
-from .repr import ReprMixin, ReprType, repr_config
-from .type import SubcatalogTypeRegister, TypeEnum, TypeMixin, TypeRegister
-from .user import UserMapping, UserMutableMapping, UserMutableSequence, UserSequence
+from tensorbay.utility.file import FileMixin, RemoteFileMixin
+from tensorbay.utility.itertools import chunked
+from tensorbay.utility.name import NameList, NameMixin, SortedNameList
+from tensorbay.utility.repr import ReprMixin, ReprType, repr_config
+from tensorbay.utility.type import TypeEnum, TypeMixin, TypeRegister
+from tensorbay.utility.user import (
+    UserMapping,
+    UserMutableMapping,
+    UserMutableSequence,
+    UserSequence,
+)
 
 __all__ = [
     "AttrsMixin",
@@ -28,14 +31,15 @@ __all__ = [
     "Deprecated",
     "Disable",
     "EqMixin",
+    "FileMixin",
     "KwargsDeprecated",
     "MatrixType",
     "NameList",
     "NameMixin",
+    "RemoteFileMixin",
     "ReprMixin",
     "ReprType",
     "SortedNameList",
-    "SubcatalogTypeRegister",
     "TypeEnum",
     "TypeMixin",
     "TypeRegister",
