@@ -26,7 +26,7 @@ from typing import (
 
 from typing_extensions import NoReturn, Protocol
 
-from ..exception import AttrError
+from tensorbay.exception import AttrError
 
 _T = TypeVar("_T")
 _Callable = Callable[[Any], Any]
@@ -36,12 +36,12 @@ _DEFAULT_ERROR_MESSAGE = "'{class_name}' object has no attribute '{attr_name}'"
 _ATTRS_BASE = "_attrs_base"
 
 
-class _A(Protocol):  # pylint: disable=too-few-public-methods
+class _A(Protocol):
     def dumps(self) -> Any:
         """Dumps all the information of attrs into a dict."""
 
 
-class Field:  # pylint: disable=too-few-public-methods, too-many-instance-attributes
+class Field:
     """A class to identify attr fields.
 
     Arguments:
@@ -49,6 +49,8 @@ class Field:  # pylint: disable=too-few-public-methods, too-many-instance-attrib
         key: Display value of the attr in contents.
         default: Default value of the attr.
         error_message: The custom error message of the attr.
+        loader: The custom loader of the attr.
+        dumper: The custom dumper of the attr.
 
     """
 
@@ -57,13 +59,19 @@ class Field:  # pylint: disable=too-few-public-methods, too-many-instance-attrib
 
     def __init__(
         self,
+        *,
         is_dynamic: bool,
         key: Union[str, None, _KeyConverter],
         default: Any,
         error_message: Optional[str],
+        loader: Optional[_Callable],
+        dumper: Optional[_Callable],
     ) -> None:
-        self.loader: _Callable
-        self.dumper: _Callable
+        if loader:
+            self.loader = loader
+
+        if dumper:
+            self.dumper = dumper
 
         self.is_dynamic = is_dynamic
         self.default = default
@@ -82,7 +90,7 @@ class Field:  # pylint: disable=too-few-public-methods, too-many-instance-attrib
         )
 
 
-class BaseField:  # pylint: disable=too-few-public-methods
+class BaseField:
     """A class to identify fields of base class.
 
     Arguments:
@@ -111,7 +119,7 @@ class AttrsMixin:
         type_ = cls.__annotations__.pop(_ATTRS_BASE, None)
         if type_:
             cls._attrs_base.loader = type_._loads  # pylint: disable=protected-access
-            cls._attrs_base.dumper = type_.dumps
+            cls._attrs_base.dumper = getattr(type_, "_dumps", type_.dumps)
 
         attrs_fields = {}
         for base_class in cls.__bases__:
@@ -121,7 +129,15 @@ class AttrsMixin:
         for name, type_ in getattr(cls, "__annotations__", {}).items():
             field = getattr(cls, name, None)
             if isinstance(field, Field):
-                field.loader, field.dumper = _get_operators(type_)
+                need_loader = not hasattr(field, "loader")
+                need_dumper = not hasattr(field, "dumper")
+                if need_loader or need_dumper:
+                    loader, dumper = _get_operators(type_)
+                    if need_loader:
+                        field.loader = loader
+                    if need_dumper:
+                        field.dumper = dumper
+
                 if hasattr(field, "key_converter"):
                     field.key = field.key_converter(name)
                 attrs_fields[name] = field
@@ -207,6 +223,8 @@ def attr(
     key: Union[str, None, _KeyConverter] = lambda x: x,
     default: Any = ...,
     error_message: Optional[str] = None,
+    loader: Optional[Callable[[Any], Any]] = None,
+    dumper: Optional[Callable[[Any], Any]] = None,
 ) -> Any:
     """Return an instance to identify attr fields.
 
@@ -215,6 +233,8 @@ def attr(
         key: Display value of the attr in contents.
         default: Default value of the attr.
         error_message: The custom error message of the attr.
+        loader: The custom loader of the attr.
+        dumper: The custom dumper of the attr.
 
     Raises:
         AttrError: Dynamic attr cannot have default value.
@@ -226,7 +246,14 @@ def attr(
     if is_dynamic and default is not ...:
         raise AttrError()
 
-    return Field(is_dynamic, key, default, error_message)
+    return Field(
+        is_dynamic=is_dynamic,
+        key=key,
+        default=default,
+        error_message=error_message,
+        loader=loader,
+        dumper=dumper,
+    )
 
 
 def attr_base(key: Optional[str] = None) -> Any:
@@ -282,7 +309,9 @@ def _get_origin_in_3_7(annotation: Any) -> Any:
 def _get_origin_in_3_6(annotation: Any) -> Any:
     module = getattr(annotation, "__module__", None)
     if module in _BUILTINS:
-        return getattr(annotation, "__extra__", None)
+        extra = getattr(annotation, "__extra__", None)
+        if extra is not None:
+            return extra
 
     return getattr(annotation, "__origin__", None)
 
@@ -305,23 +334,30 @@ def _get_operators(annotation: Any) -> Tuple[_Callable, _Callable]:
         Operating methods of the annotation.
 
     """
-    origin = _get_origin(annotation)
-    sequence: Any
+    origin: Any = _get_origin(annotation)
+    annotation_args = getattr(annotation, "__args__", ())
     if isinstance(origin, type) and issubclass(origin, Sequence):
-        sequence = origin
-        type_ = annotation.__args__[0]
+        type_ = annotation_args[0]
+    elif origin is Union and len(annotation_args) == 2 and type(None) in annotation_args:
+        type_ = annotation_args[0] if isinstance(None, annotation_args[1]) else annotation_args[1]
     else:
-        sequence = None
+        origin = None
         type_ = annotation
 
-    if {getattr(sequence, "__module__", None), getattr(type_, "__module__", None)} < _BUILTINS:
+    if {getattr(origin, "__module__", None), getattr(type_, "__module__", None)} < _BUILTINS:
         return _builtin_operator, _builtin_operator
 
-    if sequence is None:
+    if origin is None:
         return type_.loads, _attr_dumper
 
+    if origin is Union:
+        return (
+            lambda contents: type_.loads(contents) if contents is not None else None,
+            _attr_optional_dumper,
+        )
+
     return (
-        lambda contents: sequence(type_.loads(content) for content in contents),
+        lambda contents: origin(type_.loads(content) for content in contents),
         _attr_list_dumper,
     )
 
@@ -334,5 +370,11 @@ def _attr_dumper(attr_: _A) -> Any:
     return attr_.dumps()
 
 
+def _attr_optional_dumper(attr_: Optional[_A]) -> Any:
+    if attr_ is not None:
+        return attr_.dumps()
+    return None
+
+
 def _attr_list_dumper(attrs: List[_A]) -> List[Any]:
     return [attr_.dumps() for attr_ in attrs]
